# Banker

A Caching library implementing the PSR-6 interface for several common cache 
backends

## Cache Backends
* Memcache
* Memcached
* Redis
* Null - no persistence

### Basic Usage
```php
<?php
// Create the pool
// $config is the configuration array
// $logger is an optional psr/log compatible logger
$pool = new Aviat\Banker\Pool($config, $logger);

// Grab an item from the cache
$item = $pool->getItem('foo');

// Was there a cache hit?
if ( ! $item->isHit())
{
	// ... Generation of value to cache
	$item->set($value);
	$item->save();
}
else
{
	$value = $item->get();
}
```

#### Configuration / Connection array

The config array passed to the Pool class constructor determines 
which server to connect to. Regardless of the backend, the basic 
structure is like so:

```php
<?php
$config = [
	'driver' => 'null', // null, redis, memcache, memcached
	'connection' => [
		// driver setup, see below for the structure for each
		// driver
	],
	'options' => [
		// Optional:
		// Set additional driver-specific options, like persistence for
		// Memcached, or a prefix for Redis keys
	]
];
```

Below are the connection arrays for each backend:

Memcache / Memcached:
```php
<?php
$config['connection'] = [
	'host' => 'localhost', // hostname or socket
	'port' => 11211,       // Port needs to be 0 if socket
	'persistent' => false, // Use persistent connection
];
```

Redis:
See [Predis](https://github.com/nrk/predis#connecting-to-redis) documentation. An empty array will connect to localhost on port 6379.

Null:
No connection parameters