<?php declare(strict_types=1);
/**
 * Banker
 *
 * A Caching library implementing psr/cache
 *
 * PHP version 7.0
 *
 * @package     Banker
 * @author      Timothy J. Warren <tim@timshomepage.net>
 * @copyright   2016  Timothy J. Warren
 * @license     http://www.opensource.org/licenses/mit-license.html  MIT License
 * @version     1.0.0
 * @link        https://git.timshomepage.net/timw4mail/banker
 */

namespace Aviat\Banker\Driver;

use Psr\Log\LoggerAwareInterface;

/**
 * Base class for cache backends
 */
abstract class AbstractDriver implements DriverInterface, LoggerAwareInterface {

	use \Aviat\Banker\LoggerTrait;

	/**
	 * The object encapsulating the connection to the cache backend
	 *
	 * @var mixed
	 */
	protected $conn;

	/**
	 * Data to be stored later
	 *
	 * @var array
	 */
	protected $deferred = [];

	/**
	 * Common constructor interface for driver classes
	 *
	 * @param array $config - Connection parameters for the specified backend
	 * @param array $options - Special connection options for the specified backend
	 */
	abstract public function __construct(array $config = [], array $options = []);

	/**
	 * Common destructor
	 */
	abstract public function __destruct();
}